package com.melot.kkcommon.util

import android.content.Intent
import android.net.Uri
import android.text.TextUtils
import com.melot.kkcommon.CommonSetting
import com.melot.kkcommon.KKType
import com.melot.kkcommon.R
import com.melot.kkcommon.cfg.AppConfig
import com.melot.kkcommon.sns.httpnew.HttpTaskManager
import com.melot.kkcommon.sns.httpnew.reqtask.EncryptAccountReq
import com.melot.kkcommon.sns.httpnew.reqtask.GetUserLiveStateReq
import com.melot.kkcommon.struct.EncryptAccount
import com.melot.kkcommon.util.Util.getApplicationContext

/**
 * Created by siwen.hu on 2017/8/31.
 */

object UrlChecker {

    private const val M_URL_ROOM_1 = "http://www.kktv1.com/m/?roomid="
    private const val M_URL_ROOM_5 = "http://www.kktv5.com/m/?roomid="
    private const val WEB_URL_ROOM_1 = "http://www.kktv1.com/"
    private const val WEB_URL_ROOM_5 = "http://www.kktv5.com/"

    interface UrlCheckerListener {
        fun toRoom(finalRoomId: Long, finalRoomSource: Int, finalStreamType: Int)

        fun toNameCard(finalRoomId: Long)

        fun toWeb(url: String)
    }

    fun check(url: String?, checkerListener: UrlCheckerListener?) {
        if (url.isNullOrBlank()) {
            return
        }
//        var url = "https://mobile.shihanbainian.com/h5/kk_shihan/good_detail.html?id=724"
        if (checkUrl(url)) {
            val uri = Uri.parse(url)
            try {
                val roomIdStr = uri.getQueryParameter("roomid")
                var roomId: Long = 0
                if (roomIdStr.isNullOrBlank().not())
                    roomId = roomIdStr.toLong()
                val roomsourceStr = uri.getQueryParameter("roomSource")
                var roomSource = KKType.RoomSourceType.TYPE_MESHOW
                if (roomsourceStr.isNullOrBlank().not()) {
                    roomSource = roomsourceStr.toInt()
                }
                val screentypeStr = uri.getQueryParameter("screenType")
                var streamType = KKType.StreamType.TYPE_HORI
                if (screentypeStr.isNullOrBlank().not()) {
                    streamType = screentypeStr.toInt()
                }
                if (roomId > 0) {
                    val finalStreamType = streamType
                    val finalRoomSource = roomSource
                    val finalRoomId = roomId
                    HttpTaskManager.getInstance().request(GetUserLiveStateReq(roomId) { pp ->
                        if (pp.liveType > 0) {
                            checkerListener?.toRoom(finalRoomId, finalRoomSource, finalStreamType)
                        } else {
                            checkerListener?.toNameCard(finalRoomId)
                        }
                    })
                } else {
                    url?.let {
                        checkerListener?.toWeb(it)
                    }
                }
            } catch (e: NumberFormatException) {
                e.printStackTrace()
            }

        }else if (url != null && url.contains(AppConfig.getInstance().meshowConfig.specialUrl)){
            Util.showToast(getApplicationContext().getString(R.string.kk_go_to_third_party_page))
            CommonSetting.getInstance().shiHanUrl = url
            if (!CommonSetting.getInstance().isVisitor){
                HttpTaskManager.getInstance().request(EncryptAccountReq( CommonSetting.getInstance().userId, CommonSetting.getInstance().token, EncryptAccountReq.TYPE_SHIHAN){
                    if (it.isSuccess){
                        var encryptAccount = it.value
                        if (encryptAccount != null){
                            checkerListener?.toWeb(Util.getShiHanUrl(encryptAccount.userId,encryptAccount.token))
                        }
                    }
                })
            }else{
                checkerListener?.toWeb(Util.getShiHanUrl("",""))
            }
        } else {
            url?.let {
                checkerListener?.toWeb(it)
            }
        }
    }

    /**
     * @param url
     */
    private infix fun checkUrl(url: String?): Boolean {
        url?.let {
            if (it.startsWith(M_URL_ROOM_1) || it.startsWith(M_URL_ROOM_5)) {
                return true
            } else if (it.startsWith(WEB_URL_ROOM_1) || it.startsWith(WEB_URL_ROOM_5)) {
                return true
            }
        }
        return false
    }
}
